pub enum WriteError {
InconsistentFieldCount {
expected: usize,
found: usize,
row: usize,
},
HeadersAlreadyWritten,
Serialize(String),
Io(Error),
}Expand description
An error returned when writing CSV data.
Variants
InconsistentFieldCount
The number of fields in a row differs from previous rows.
HeadersAlreadyWritten
A second attempt was made to write headers after they’ve already been written.
Serialize(String)
A serde serialization error occurred.
Io(Error)
An I/O error occurred while writing.