Row

Struct Row 

pub struct Row { /* private fields */ }

Implementations

Source

impl Row

pub fn error(&self) -> Option<&ReadError>

pub fn len(&self) -> usize

pub fn is_empty(&self) -> bool

pub fn get(&self, index: usize) -> Option<Result<&str, ReadError>>

pub fn to_vec(&self) -> Result<Vec<&str>, ReadError>

pub fn iter(&self) -> Fields<'_>

Source

impl Row

pub fn deserialize<T>(&self) -> Result<T, ReadError>

Deserialize this row into a T.

Headers must have been set on the parent Reader via parse_headers or set_headers before calling this method. Struct fields are matched by column name.

Errors

Returns ReadError with kind Deserialize if headers have not been set, or if deserialization fails (type mismatch, unknown field, etc.).

Example
use csv::Reader;
use serde::Deserialize;

#[derive(Deserialize)]
struct Record { name: String, age: u32 }

let mut reader = Reader::new(std::io::Cursor::new(b"name,age\nAlice,30\n"));
reader.parse_headers()?;
for row in reader.rows() {
    let rec: Record = row.deserialize()?;
    println!("{} is {}", rec.name, rec.age);
}